@@ -3,11 +3,6 @@
 
 package config
 
-import (
-	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/config/data"
-)
-
 const (
 	// DefaultLoggerTailCount tracks default log tail size.
 	DefaultLoggerTailCount = 100
@@ -39,7 +34,7 @@ func NewLogger() *Logger {
 }
 
 // Validate checks thresholds and make sure we're cool. If not use defaults.
-func (l *Logger) Validate(_ client.Connection, _ data.KubeSettings) {
+func (l *Logger) Validate() {
 	if l.TailCount <= 0 {
 		l.TailCount = DefaultLoggerTailCount
 	}
