@@ -4,8 +4,6 @@
 package config
 
 import (
-	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/config/data"
 	v1 "k8s.io/api/core/v1"
 )
 
@@ -37,7 +35,7 @@ func NewShellPod() *ShellPod {
 }
 
 // Validate validates the configuration.
-func (s *ShellPod) Validate(client.Connection, data.KubeSettings) {
+func (s *ShellPod) Validate() {
 	if s.Image == "" {
 		s.Image = defaultDockerShellImage
 	}
