@@ -70,7 +70,7 @@ func (p *Pod) Get(ctx context.Context, path string) (runtime.Object, error) {
 	}
 
 	var pmx *mv1beta1.PodMetrics
-	if withMx, ok := ctx.Value(internal.KeyWithMetrics).(bool); withMx || !ok {
+	if withMx, ok := ctx.Value(internal.KeyWithMetrics).(bool); ok && withMx {
 		pmx, _ = client.DialMetrics(p.Client()).FetchPodMetrics(ctx, path)
 	}
 
@@ -95,7 +95,7 @@ func (p *Pod) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 	}
 
 	var pmx client.PodsMetricsMap
-	if withMx, ok := ctx.Value(internal.KeyWithMetrics).(bool); withMx || !ok {
+	if withMx, ok := ctx.Value(internal.KeyWithMetrics).(bool); ok && withMx {
 		pmx, _ = client.DialMetrics(p.Client()).FetchPodsMetricsMap(ctx, ns)
 	}
 	sel, _ := ctx.Value(internal.KeyFields).(string)
@@ -268,7 +268,7 @@ func (p *Pod) ScanSA(ctx context.Context, fqn string, wait bool) (Refs, error) {
 }
 
 // Scan scans for cluster resource refs.
-func (p *Pod) Scan(ctx context.Context, gvr, fqn string, wait bool) (Refs, error) {
+func (p *Pod) Scan(ctx context.Context, gvr client.GVR, fqn string, wait bool) (Refs, error) {
 	ns, n := client.Namespaced(fqn)
 	oo, err := p.GetFactory().List(p.GVR(), ns, wait, labels.Everything())
 	if err != nil {
@@ -287,7 +287,7 @@ func (p *Pod) Scan(ctx context.Context, gvr, fqn string, wait bool) (Refs, error
 			continue
 		}
 		switch gvr {
-		case "v1/configmaps":
+		case CmGVR:
 			if !hasConfigMap(&pod.Spec, n) {
 				continue
 			}
@@ -295,7 +295,7 @@ func (p *Pod) Scan(ctx context.Context, gvr, fqn string, wait bool) (Refs, error
 				GVR: p.GVR(),
 				FQN: client.FQN(pod.Namespace, pod.Name),
 			})
-		case "v1/secrets":
+		case SecGVR:
 			found, err := hasSecret(p.Factory, &pod.Spec, pod.Namespace, n, wait)
 			if err != nil {
 				log.Warn().Err(err).Msgf("locate secret %q", fqn)
@@ -308,7 +308,7 @@ func (p *Pod) Scan(ctx context.Context, gvr, fqn string, wait bool) (Refs, error
 				GVR: p.GVR(),
 				FQN: client.FQN(pod.Namespace, pod.Name),
 			})
-		case "v1/persistentvolumeclaims":
+		case PvcGVR:
 			if !hasPVC(&pod.Spec, n) {
 				continue
 			}
@@ -316,7 +316,7 @@ func (p *Pod) Scan(ctx context.Context, gvr, fqn string, wait bool) (Refs, error
 				GVR: p.GVR(),
 				FQN: client.FQN(pod.Namespace, pod.Name),
 			})
-		case "scheduling.k8s.io/v1/priorityclasses":
+		case PcGVR:
 			if !hasPC(&pod.Spec, n) {
 				continue
 			}
@@ -536,6 +536,8 @@ func (p *Pod) Sanitize(ctx context.Context, ns string) (int, error) {
 		switch render.PodStatus(&pod) {
 		case render.PhaseCompleted:
 			fallthrough
+		case render.PhasePending:
+			fallthrough
 		case render.PhaseCrashLoop:
 			fallthrough
 		case render.PhaseError:
@@ -543,9 +545,11 @@ func (p *Pod) Sanitize(ctx context.Context, ns string) (int, error) {
 		case render.PhaseImagePullBackOff:
 			fallthrough
 		case render.PhaseOOMKilled:
+			// !!BOZO!! Might need to bump timeout otherwise rev limit if too many??
 			log.Debug().Msgf("Sanitizing %s:%s", pod.Namespace, pod.Name)
 			fqn := client.FQN(pod.Namespace, pod.Name)
-			if err := p.Resource.Delete(ctx, fqn, nil, NowGrace); err != nil {
+			if err := p.Delete(ctx, fqn, nil, 0); err != nil {
+				log.Debug().Msgf("Aborted! Sanitizer deleted %d pods", count)
 				return count, err
 			}
 			count++
