@@ -39,7 +39,7 @@ func NewApp(cfg *config.Config, context string) *App {
 		flash:        model.NewFlash(model.DefaultFlashDelay),
 		cmdBuff:      model.NewFishBuff(':', model.CommandBuffer),
 	}
-	a.ReloadStyles(context)
+	a.ReloadStyles()
 
 	a.views = map[string]tview.Primitive{
 		"menu":   NewMenu(a.Styles),
@@ -135,8 +135,8 @@ func (a *App) StylesChanged(s *config.Styles) {
 }
 
 // ReloadStyles reloads skin file.
-func (a *App) ReloadStyles(context string) {
-	a.RefreshStyles(context)
+func (a *App) ReloadStyles() {
+	a.RefreshStyles()
 }
 
 // Conn returns an api server connection.
