@@ -58,6 +58,9 @@ func NewDetails(app *App, title, subject, contentType string, searchable bool) *
 	return &d
 }
 
+func (d *Details) SetFilter(string)                 {}
+func (d *Details) SetLabelFilter(map[string]string) {}
+
 // Init initializes the viewer.
 func (d *Details) Init(_ context.Context) error {
 	if d.title != "" {
@@ -102,19 +105,12 @@ func (d *Details) TextChanged(lines []string) {
 
 // TextFiltered notifies when the filter changed.
 func (d *Details) TextFiltered(lines []string, matches fuzzy.Matches) {
-	d.currentRegion, d.maxRegions = 0, 0
-
-	ll := make([]string, len(lines))
-	copy(ll, lines)
-	for _, m := range matches {
-		loc, line := m.MatchedIndexes, ll[m.Index]
-		ll[m.Index] = line[:loc[0]] + fmt.Sprintf(`<<<"search_%d">>>`, d.maxRegions) + line[loc[0]:loc[1]] + `<<<"">>>` + line[loc[1]:]
-		d.maxRegions++
-	}
+	d.currentRegion, d.maxRegions = 0, len(matches)
+	ll := linesWithRegions(lines, matches)
 
 	d.text.SetText(colorizeYAML(d.app.Styles.Views().Yaml, strings.Join(ll, "\n")))
 	d.text.Highlight()
-	if d.maxRegions > 0 {
+	if len(matches) > 0 {
 		d.text.Highlight("search_0")
 		d.text.ScrollToHighlight()
 	}
@@ -301,7 +297,7 @@ func (d *Details) resetCmd(evt *tcell.EventKey) *tcell.EventKey {
 }
 
 func (d *Details) saveCmd(evt *tcell.EventKey) *tcell.EventKey {
-	if path, err := saveYAML(d.app.Config.K9s.GetScreenDumpDir(), d.app.Config.K9s.CurrentContextDir(), d.title, d.text.GetText(true)); err != nil {
+	if path, err := saveYAML(d.app.Config.K9s.ActiveScreenDumpsDir(), d.title, d.text.GetText(true)); err != nil {
 		d.app.Flash().Err(err)
 	} else {
 		d.app.Flash().Infof("Log %s saved successfully!", path)
