@@ -478,11 +478,11 @@ func (x *Xray) filter(root *xray.TreeNode) *xray.TreeNode {
 	}
 
 	x.UpdateTitle()
-	if ui.IsFuzzySelector(q) {
-		return root.Filter(q, fuzzyFilter)
+	if f, ok := dao.HasFuzzySelector(q); ok {
+		return root.Filter(f, fuzzyFilter)
 	}
 
-	if ui.IsInverseSelector(q) {
+	if dao.IsInverseSelector(q) {
 		return root.Filter(q, rxInverseFilter)
 	}
 
