@@ -12,6 +12,7 @@ import (
 	"time"
 
 	"github.com/derailed/k9s/internal/config"
+	"github.com/derailed/k9s/internal/config/data"
 	"github.com/derailed/tview"
 	"github.com/rs/zerolog/log"
 )
@@ -62,18 +63,17 @@ func enableRegion(str string) string {
 	return strings.ReplaceAll(strings.ReplaceAll(str, "<<<", "["), ">>>", "]")
 }
 
-func saveYAML(screenDumpDir, context, name, data string) (string, error) {
-	dir := filepath.Join(screenDumpDir, config.SanitizeFilename(context))
+func saveYAML(dir, name, raw string) (string, error) {
 	if err := ensureDir(dir); err != nil {
 		return "", err
 	}
 
-	fName := fmt.Sprintf("%s--%d.yml", config.SanitizeFilename(name), time.Now().Unix())
-	path := filepath.Join(dir, fName)
+	fName := fmt.Sprintf("%s--%d.yaml", data.SanitizeFileName(name), time.Now().Unix())
+	fpath := filepath.Join(dir, fName)
 	mod := os.O_CREATE | os.O_WRONLY
-	file, err := os.OpenFile(path, mod, 0600)
+	file, err := os.OpenFile(fpath, mod, 0600)
 	if err != nil {
-		log.Error().Err(err).Msgf("YAML create %s", path)
+		log.Error().Err(err).Msgf("YAML create %s", fpath)
 		return "", nil
 	}
 	defer func() {
@@ -81,9 +81,9 @@ func saveYAML(screenDumpDir, context, name, data string) (string, error) {
 			log.Error().Err(err).Msg("Closing yaml file")
 		}
 	}()
-	if _, err := file.Write([]byte(data)); err != nil {
+	if _, err := file.Write([]byte(raw)); err != nil {
 		return "", err
 	}
 
-	return path, nil
+	return fpath, nil
 }
